Crate ps_compress

Crate ps_compress 

Deterministic Zstandard compression helpers for small payloads.

This crate fixes compression policy to produce stable output for identical inputs.

Enums

CompressionError
DecompressionError

Functions

compress
Compresses data and allocates an output buffer for the compressed bytes.
compress_into
Compresses data into an existing output buffer.
decompress
Decompresses data, allocating an output buffer sized from frame metadata.
decompress_bounded
Decompresses data, allocating an output buffer up to max_output_bytes.
decompress_into
Decompresses data into an existing output buffer.