Deterministic Zstandard compression helpers for small payloads.
This crate fixes compression policy to produce stable output for identical inputs.
Enums
Functions
- compress
- Compresses
dataand allocates an output buffer for the compressed bytes. - compress_
into - Compresses
datainto an existing output buffer. - decompress
- Decompresses
data, allocating an output buffer sized from frame metadata. - decompress_
bounded - Decompresses
data, allocating an output buffer up tomax_output_bytes. - decompress_
into - Decompresses
datainto an existing output buffer.